API Reference
=============

Parser
------

.. automodule:: paftacular.parser
   :members:
   :undoc-members:
   :show-inheritance:

Annotation Types
----------------

.. automodule:: paftacular.comps
   :members:
   :undoc-members:
   :inherited-members:
   
Constants
---------

.. automodule:: paftacular.constants
   :members:
   :undoc-members:
   :show-inheritance:

Utilities
---------

.. automodule:: paftacular.util
   :members:
   :undoc-members:
   :show-inheritance:
